@@ -5,79 +5,39 @@ use warnings;
 use Carp qw/croak/;
 use MooX::ReturnModifiers;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub import {
 	my ( $self, @import ) = @_;
-
 	my $target = caller;
-
 	my %modifiers = return_modifiers($target);
-
-	my @target_isa;
-
-	{ no strict 'refs'; @target_isa = @{"${target}::ISA"} };
-
-	if (@target_isa) {   
-		eval '{
-			package ' . $target . ';
-		    
-			sub _build_line_spec {
-				my ($class, @meta) = @_;
-				return $class->maybe::next::method(@meta);
-			}
-
-			sub _build_all_spec {
-				my ($class, @meta) = @_;
-				return $class->maybe::next::method(@meta);
-			}
-			    
-			1;
-		}';
-    	}
-
 	$modifiers{has}->( 'target' => ( is => 'ro', lazy => 1, default => sub { return $target; } ) );
-
-	my $apply_modifiers = sub {
-		$modifiers{with}->('MooX::Pack::Base');
-	};
-
-	my $spec = {};
-	my $index = 0;
-	my $line = sub {
+	my ($spec, $aspec, $index) = ({}, undef, 0);
+	{ no strict 'refs'; *{"${target}::line"} = sub {
 		my ( $name, %attributes ) = @_;
 		if (!$spec->{$name}) { 
 			$spec->{$name}->{spec} = [];
 			$spec->{$name}->{index} = $index++;
 		}
 		push @{ $spec->{$name}->{spec} }, \%attributes;
-		$modifiers{around}->(
-			"_build_line_spec" => sub {
-				my ( $orig, $self ) = ( shift, shift );
-				return $self->$orig(@_), $spec;
-			}
-		);
-	};
-
-	{ no strict 'refs'; *{"${target}::line"} = $line; }
-
-	my $aspec = {};
-	my $option = sub {
-		my ( $name, %attributes ) = @_;
-		$aspec->{$name} = \%attributes;
-		$modifiers{around}->(
-			"_build_all_spec" => sub {
-				my ( $orig, $self ) = ( shift, shift );
-				return $self->$orig(@_), $aspec;
-			}
-		);
-	};
-
-	{ no strict 'refs'; *{"${target}::all"} = $option; }
-
-	$apply_modifiers->();
-
-	return; 
+	}; }
+	{ no strict 'refs'; *{"${target}::seperator"} = sub {
+		my ( %attributes ) = @_;
+		$aspec = \%attributes;
+	}; }
+	$modifiers{with}->('MooX::Pack::Base');
+	$modifiers{sub}->(
+		"_build_line_spec" => sub {
+			my ( $orig, $self ) = ( shift, shift );
+			return $spec;
+		}
+	);
+	$modifiers{sub}->(
+		"_build_all_spec" => sub {
+			my ( $orig, $self ) = ( shift, shift );
+			return $aspec;
+		}
+	);
 }
 
 1;
@@ -90,7 +50,7 @@ MooX::Pack - The great new MooX::Pack!
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
@@ -101,46 +61,44 @@ Version 0.02
 	use Moo;
 	use MooX::Pack;
 
-	all seperator => (
+	seperator (
 		character => 'x',
 		pack => '|',
-		index => [ 1, 3 ],
 	);
-
 		
-	line one => (
+	line heading => (
 		key => 'data',
 		character => 'A10',
 		catch => 1,
 	);
 
-	line one => (
+	line heading => (
 		name => 'description',
 		character => 'A27',
 		catch => 1,
 	);
 
-	line one => (
+	line heading => (
 		name => 'income',
 		character => 'A7',
 		catch => 1,
 	);
 
-	line two => (
+	line rest => (
 		name => 'first name',
 		character => 'A20',
 		catch => 1,
 		index => 4,
 	);
 
-	line two => (
+	line rest => (
 		key => 'last name',
 		character => 'A20',
 		catch => 1,
 		index => 0,
 	);
 
-	line two => (
+	line rest => (
 		name => 'age',
 		character => 'A3',
 		catch => 1,
@@ -153,7 +111,7 @@ Version 0.02
 
 	$memory->raw_data(
 q{
-Public    |Property                   |None   
+Public    |Property                   |NA     
 Robert              |Acock               |32 
 }
 	);
